pub struct FileStat {
pub file_type: FileType,
pub ctime: i128,
pub mtime: i128,
pub size: usize,
}Fields
file_type: FileTypeThe type of the file, e.g. is a regular file, a directory, or symbolic link to a file.
ctime: i128The creation timestamp in milliseconds elapsed since January 1, 1970 00:00:00 UTC.
mtime: i128The modification timestamp in milliseconds elapsed since January 1, 1970 00:00:00 UTC.
size: usizeThe size in bytes.