pub struct HTMLLanguageServiceOptions {
pub use_default_data_provider: Option<bool>,
pub file_system_provider: Option<Box<dyn FileSystemProvider>>,
pub client_capabilities: Option<ClientCapabilities>,
}Fields
use_default_data_provider: Option<bool>Unless set to false, the default HTML data provider will be used along with the providers from customDataProviders. Defaults to true.
file_system_provider: Option<Box<dyn FileSystemProvider>>Provide data that could enhance the service’s understanding of HTML tag / attribute / attribute-value Abstract file system access away from the service. Used for path completion, etc.
client_capabilities: Option<ClientCapabilities>Describes the LSP capabilities the client supports.